@@ -26,7 +26,7 @@ gt=$build
 #chrlist=$(/work/git/script_rnakato/getchr_from_genometable.sh $gt)
 length=`awk '$1 == "'$chrlist'" {print $2}' $gt`
 seq 0 $binsize $length > rowname.temp
-cat rowname.temp|  tr '\n' '\t' > colname.temp
+cat rowname.temp|  tr '\n' '\t'| sed "s/$/\n/g" > colname.temp
 sed '1{x;p;x}' rowname.temp > rowname2.temp
 
 dir=$matrixdir/${outname}/$binsize
